==> jbosgi-wildfly-web-2.3.1.Final-sources.jar: org/jboss/as/osgi/web/RemountDeploymentRootProcessor.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.osgi.web;

import java.io.Closeable;
import java.io.IOException;
import java.util.jar.Manifest;

import org.jboss.as.server.ServerMessages;
import org.jboss.as.server.deployment.Attachments;
import org.jboss.as.server.deployment.DeploymentMountProvider;
import org.jboss.as.server.deployment.DeploymentPhaseContext;
import org.jboss.as.server.deployment.DeploymentUnit;
import org.jboss.as.server.deployment.DeploymentUnitProcessingException;
import org.jboss.as.server.deployment.DeploymentUnitProcessor;
import org.jboss.as.server.deployment.MountExplodedMarker;
import org.jboss.as.server.deployment.MountType;
import org.jboss.as.server.deployment.module.ModuleRootMarker;
import org.jboss.as.server.deployment.module.MountHandle;
import org.jboss.as.server.deployment.module.ResourceRoot;
import org.jboss.as.web.common.WebApplicationBundleUtils;
import org.jboss.vfs.VFS;
import org.jboss.vfs.VFSUtils;
import org.jboss.vfs.VirtualFile;

/**
 * Processor that remounts a deployment exploded.
 *
 * @author Thomas.Diesler@jboss.com
 * @since  11-Sep-2012
 *
 * @see {@link org.jboss.as.server.deployment.module.DeploymentRootMountProcessor}
 */
public class RemountDeploymentRootProcessor implements DeploymentUnitProcessor {

    @Override
    public void deploy(final DeploymentPhaseContext phaseContext) throws DeploymentUnitProcessingException {
        DeploymentUnit depUnit = phaseContext.getDeploymentUnit();
        Manifest manifest = depUnit.getAttachment(Attachments.OSGI_MANIFEST);
        if (manifest == null || MountExplodedMarker.isMountExploded(depUnit))
            return;

        // Check for WAB
        if (!WebApplicationBundleUtils.isWebApplicationBundle(depUnit))
            return;

        // Close the already mounted root
        ResourceRoot resourceRoot = depUnit.getAttachment(Attachments.DEPLOYMENT_ROOT);
        Closeable handle = resourceRoot.getMountHandle();
        VFSUtils.safeClose(handle);

        VirtualFile deploymentContents = depUnit.getAttachment(Attachments.DEPLOYMENT_CONTENTS);
        DeploymentMountProvider deploymentMountProvider = depUnit.getAttachment(Attachments.SERVER_DEPLOYMENT_REPOSITORY);
        VirtualFile deploymentRoot = VFS.getChild("content/" + depUnit.getName());

        MountHandle mountHandle;
        try {
            handle = deploymentMountProvider.mountDeploymentContent(deploymentContents, deploymentRoot, MountType.EXPANDED);
            mountHandle = new MountHandle(handle);
        } catch (IOException e) {
            VFSUtils.safeClose(handle);
            throw ServerMessages.MESSAGES.deploymentMountFailed(e);
        }

        resourceRoot = new ResourceRoot(deploymentRoot, mountHandle);
        resourceRoot.putAttachment(Attachments.MANIFEST, manifest);
        ModuleRootMarker.mark(resourceRoot);

        depUnit.putAttachment(Attachments.DEPLOYMENT_ROOT, resourceRoot);
    }

    @Override
    public void undeploy(final DeploymentUnit depUnit) {
    }
}

==> jbosgi-wildfly-web-2.4.1.Final-sources.jar: org/jboss/as/osgi/web/RemountDeploymentRootProcessor.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.osgi.web;

import java.io.Closeable;
import java.io.IOException;
import java.util.jar.Manifest;

import org.jboss.as.server.deployment.Attachments;
import org.jboss.as.server.deployment.DeploymentMountProvider;
import org.jboss.as.server.deployment.DeploymentPhaseContext;
import org.jboss.as.server.deployment.DeploymentUnit;
import org.jboss.as.server.deployment.DeploymentUnitProcessingException;
import org.jboss.as.server.deployment.DeploymentUnitProcessor;
import org.jboss.as.server.deployment.MountExplodedMarker;
import org.jboss.as.server.deployment.MountType;
import org.jboss.as.server.deployment.module.ModuleRootMarker;
import org.jboss.as.server.deployment.module.MountHandle;
import org.jboss.as.server.deployment.module.ResourceRoot;
import org.jboss.as.server.logging.ServerLogger;
import org.jboss.as.web.common.WebApplicationBundleUtils;
import org.jboss.vfs.VFS;
import org.jboss.vfs.VFSUtils;
import org.jboss.vfs.VirtualFile;

/**
 * Processor that remounts a deployment exploded.
 *
 * @author Thomas.Diesler@jboss.com
 * @since  11-Sep-2012
 *
 * @see {@link org.jboss.as.server.deployment.module.DeploymentRootMountProcessor}
 */
public class RemountDeploymentRootProcessor implements DeploymentUnitProcessor {

    @Override
    public void deploy(final DeploymentPhaseContext phaseContext) throws DeploymentUnitProcessingException {
        DeploymentUnit depUnit = phaseContext.getDeploymentUnit();
        Manifest manifest = depUnit.getAttachment(Attachments.OSGI_MANIFEST);
        if (manifest == null || MountExplodedMarker.isMountExploded(depUnit))
            return;

        // Check for WAB
        if (!WebApplicationBundleUtils.isWebApplicationBundle(depUnit))
            return;

        // Close the already mounted root
        ResourceRoot resourceRoot = depUnit.getAttachment(Attachments.DEPLOYMENT_ROOT);
        Closeable handle = resourceRoot.getMountHandle();
        VFSUtils.safeClose(handle);

        VirtualFile deploymentContents = depUnit.getAttachment(Attachments.DEPLOYMENT_CONTENTS);
        DeploymentMountProvider deploymentMountProvider = depUnit.getAttachment(Attachments.SERVER_DEPLOYMENT_REPOSITORY);
        VirtualFile deploymentRoot = VFS.getChild("content/" + depUnit.getName());

        MountHandle mountHandle;
        try {
            handle = deploymentMountProvider.mountDeploymentContent(deploymentContents, deploymentRoot, MountType.EXPANDED);
            mountHandle = new MountHandle(handle);
        } catch (IOException e) {
            VFSUtils.safeClose(handle);
            throw ServerLogger.ROOT_LOGGER.deploymentMountFailed(e);
        }

        resourceRoot = new ResourceRoot(deploymentRoot, mountHandle);
        resourceRoot.putAttachment(Attachments.MANIFEST, manifest);
        ModuleRootMarker.mark(resourceRoot);

        depUnit.putAttachment(Attachments.DEPLOYMENT_ROOT, resourceRoot);
    }

    @Override
    public void undeploy(final DeploymentUnit depUnit) {
    }
}
